@@ -453,8 +453,8 @@ class Series(BasePandasDataset):
         -------
         str
         """
-        num_rows = pandas.get_option("max_rows") or 60
-        num_cols = pandas.get_option("max_columns") or 20
+        num_rows = pandas.get_option("display.max_rows") or 60
+        num_cols = pandas.get_option("display.max_columns") or 20
         temp_df = self._build_repr_df(num_rows, num_cols)
         if isinstance(temp_df, pandas.DataFrame) and not temp_df.empty:
             temp_df = temp_df.iloc[:, 0]
@@ -543,7 +543,7 @@ class Series(BasePandasDataset):
         """
         Return Series as ndarray or ndarray-like depending on the dtype.
         """
-        return super(Series, self).to_numpy().flatten()
+        return self.to_numpy()
 
     def add(self, other, level=None, fill_value=None, axis=0):  # noqa: PR01, RT01, D200
         """
@@ -681,19 +681,12 @@ class Series(BasePandasDataset):
         # the return type.
         try:
             return_type = type(
-                getattr(pandas.Series("", index=self.index[:1]), apply_func)(
-                    func, *args, **kwargs
-                )
+                getattr(
+                    pandas.Series(self[:1].values, index=self.index[:1]), apply_func
+                )(func, *args, **kwargs)
             ).__name__
         except Exception:
-            try:
-                return_type = type(
-                    getattr(pandas.Series(0, index=self.index[:1]), apply_func)(
-                        func, *args, **kwargs
-                    )
-                ).__name__
-            except Exception:
-                return_type = type(self).__name__
+            return_type = type(self).__name__
         if (
             isinstance(func, str)
             or is_list_like(func)
@@ -1004,7 +997,9 @@ class Series(BasePandasDataset):
         """
         Transform each element of a list-like to a row.
         """
-        return self._default_to_pandas(pandas.Series.explode, ignore_index=ignore_index)
+        return super(Series, self).explode(
+            "__reduced__" if self.name is None else self.name, ignore_index=ignore_index
+        )
 
     def factorize(self, sort=False, na_sentinel=-1):  # noqa: PR01, RT01, D200
         """
@@ -1166,6 +1161,23 @@ class Series(BasePandasDataset):
             skipna = True
         return super(Series, self).idxmin(axis=axis, skipna=skipna, *args, **kwargs)
 
+    def info(
+        self,
+        verbose: "bool | None" = None,
+        buf: "IO[str] | None" = None,
+        max_cols: "int | None" = None,
+        memory_usage: "bool | str | None" = None,
+        show_counts: "bool" = True,
+    ):
+        return self._default_to_pandas(
+            pandas.Series.info,
+            verbose=verbose,
+            buf=buf,
+            max_cols=max_cols,
+            memory_usage=memory_usage,
+            show_counts=show_counts,
+        )
+
     def interpolate(
         self,
         method="linear",
@@ -1223,7 +1235,12 @@ class Series(BasePandasDataset):
         return self.index
 
     def kurt(
-        self, axis=None, skipna=None, level=None, numeric_only=None, **kwargs
+        self,
+        axis: "Axis | None | NoDefault" = no_default,
+        skipna=True,
+        level=None,
+        numeric_only=None,
+        **kwargs,
     ):  # noqa: PR01, RT01, D200
         """
         Return unbiased kurtosis over requested axis.
@@ -1267,6 +1284,27 @@ class Series(BasePandasDataset):
             )
         )
 
+    def mask(
+        self,
+        cond,
+        other=np.nan,
+        inplace=False,
+        axis=None,
+        level=None,
+        errors=no_default,
+        try_cast=no_default,
+    ):
+        return self._default_to_pandas(
+            pandas.Series.mask,
+            cond,
+            other=other,
+            inplace=inplace,
+            axis=axis,
+            level=level,
+            errors=errors,
+            try_cast=try_cast,
+        )
+
     def memory_usage(self, index=True, deep=False):  # noqa: PR01, RT01, D200
         """
         Return the memory usage of the Series.
@@ -1335,14 +1373,10 @@ class Series(BasePandasDataset):
             if abs(periods) >= len(self.index):
                 return Series(dtype=self.dtype)
             else:
-                if periods > 0:
-                    new_index = self.index.drop(labels=self.index[:periods])
-                    new_df = self.drop(self.index[-periods:])
-                else:
-                    new_index = self.index.drop(labels=self.index[periods:])
-                    new_df = self.drop(self.index[:-periods])
-
-                new_df.index = new_index
+                new_df = self.iloc[:-periods] if periods > 0 else self.iloc[-periods:]
+                new_df.index = (
+                    self.index[periods:] if periods > 0 else self.index[:periods]
+                )
                 return new_df
         else:
             raise ValueError(
@@ -1418,7 +1452,7 @@ class Series(BasePandasDataset):
     def prod(
         self,
         axis=None,
-        skipna=None,
+        skipna=True,
         level=None,
         numeric_only=None,
         min_count=0,
@@ -1428,6 +1462,7 @@ class Series(BasePandasDataset):
         Return the product of the values over the requested `axis`.
         """
         axis = self._get_axis_number(axis)
+        validate_bool_kwarg(skipna, "skipna", none_allowed=False)
         if level is not None:
             if (
                 not self._query_compiler.has_multiindex(axis=axis)
@@ -1483,10 +1518,19 @@ class Series(BasePandasDataset):
 
         return data
 
-    def reindex(self, index=None, **kwargs):  # noqa: PR01, RT01, D200
+    def reindex(self, *args, **kwargs):  # noqa: PR01, RT01, D200
         """
         Conform Series to new index with optional filling logic.
         """
+        if args:
+            if len(args) > 1:
+                raise TypeError("Only one positional argument ('index') is allowed")
+            if "index" in kwargs:
+                raise TypeError(
+                    "'index' passed as both positional and keyword argument"
+                )
+            kwargs.update({"index": args[0]})
+        index = kwargs.pop("index", None)
         method = kwargs.pop("method", None)
         level = kwargs.pop("level", None)
         copy = kwargs.pop("copy", True)
@@ -1550,16 +1594,20 @@ class Series(BasePandasDataset):
         return self.__constructor__(query_compiler=self._query_compiler.repeat(repeats))
 
     def reset_index(
-        self, level=None, drop=False, name=None, inplace=False
+        self, level=None, drop=False, name=no_default, inplace=False
     ):  # noqa: PR01, RT01, D200
         """
         Generate a new Series with the index reset.
         """
+        if name is no_default:
+            # For backwards compatibility, keep columns as [0] instead of
+            #  [None] when self.name is None
+            name = 0 if self.name is None else self.name
+
         if drop and level is None:
             new_idx = pandas.RangeIndex(len(self.index))
             if inplace:
                 self.index = new_idx
-                self.name = name or self.name
             else:
                 result = self.copy()
                 result.index = new_idx
@@ -1570,8 +1618,7 @@ class Series(BasePandasDataset):
             )
         else:
             obj = self.copy()
-            if name is not None:
-                obj.name = name
+            obj.name = name
             from .dataframe import DataFrame
 
             return DataFrame(obj).reset_index(level=level, drop=drop, inplace=inplace)
@@ -1660,11 +1707,11 @@ class Series(BasePandasDataset):
     def replace(
         self,
         to_replace=None,
-        value=None,
+        value=no_default,
         inplace=False,
         limit=None,
         regex=False,
-        method="pad",
+        method: "str | NoDefault" = no_default,
     ):  # noqa: PR01, RT01, D200
         """
         Replace values given in `to_replace` with `value`.
@@ -1777,7 +1824,7 @@ class Series(BasePandasDataset):
     def sum(
         self,
         axis=None,
-        skipna=None,
+        skipna=True,
         level=None,
         numeric_only=None,
         min_count=0,
@@ -1787,6 +1834,7 @@ class Series(BasePandasDataset):
         Return the sum of the values.
         """
         axis = self._get_axis_number(axis)
+        validate_bool_kwarg(skipna, "skipna", none_allowed=False)
         if numeric_only is True:
             raise NotImplementedError("Series.sum does not implement numeric_only")
         if level is not None:
@@ -1848,15 +1896,21 @@ class Series(BasePandasDataset):
         """
         return self._default_to_pandas("to_dict", into=into)
 
-    def to_frame(self, name=None):  # noqa: PR01, RT01, D200
+    def to_frame(
+        self, name: "Hashable" = no_default
+    ) -> "DataFrame":  # noqa: PR01, RT01, D200
         """
         Convert Series to {label -> value} dict or dict-like object.
         """
         from .dataframe import DataFrame
 
+        if name is None:
+            name = no_default
+
         self_cp = self.copy()
-        if name is not None:
+        if name is not no_default:
             self_cp.name = name
+
         return DataFrame(self_cp)
 
     def to_list(self):  # noqa: RT01, D200
@@ -1982,15 +2036,28 @@ class Series(BasePandasDataset):
         """
         Return a Series containing counts of unique values.
         """
-        return self.__constructor__(
-            query_compiler=self._query_compiler.value_counts(
+        if bins is not None:
+            # Potentially we could implement `cut` function from pandas API, which
+            # bins values into intervals, and then we can just count them as regular values.
+            # TODO #1333: new_self = Series(pd.cut(self, bins, include_lowest=True), dtype="interval")
+            return self._default_to_pandas(
+                pandas.Series.value_counts,
                 normalize=normalize,
                 sort=sort,
                 ascending=ascending,
                 bins=bins,
                 dropna=dropna,
             )
+        counted_values = super(Series, self).value_counts(
+            subset=self,
+            normalize=normalize,
+            sort=sort,
+            ascending=ascending,
+            dropna=dropna,
         )
+        # pandas sets output index names to None because the Series name already contains it
+        counted_values._query_compiler.set_index_name(None)
+        return counted_values
 
     def view(self, dtype=None):  # noqa: PR01, RT01, D200
         """
@@ -2003,11 +2070,11 @@ class Series(BasePandasDataset):
     def where(
         self,
         cond,
-        other=np.nan,
+        other=no_default,
         inplace=False,
         axis=None,
         level=None,
-        errors="raise",
+        errors=no_default,
         try_cast=no_default,
     ):  # noqa: PR01, RT01, D200
         """
